app/soc/models/reviewer.py
changeset 181 fdd29818a954
parent 54 03e267d67478
child 207 8ecc2e4198cd
--- a/app/soc/models/reviewer.py	Sun Sep 21 02:16:00 2008 +0000
+++ b/app/soc/models/reviewer.py	Sun Sep 21 08:50:42 2008 +0000
@@ -38,9 +38,9 @@
      back-reference Query of the Review model 'reviewer' reference.
   """
   
-  #: A 1:1 relationship associating a Contributor with generic Author
-  #: details and capabilities. The back-reference in the Author model
-  #: is a Query named 'contributor'.
-  author = db.ReferenceProperty(reference_class=models.author.Author,
+  #: A 1:1 relationship associating a Contributor with Person
+  #: details and capabilities. The back-reference in the Person model
+  #: is a Query named 'reviewer'.
+  person = db.ReferenceProperty(reference_class=models.person.Person,
                                 required=True, collection_name="reviewer")